@@ -12,9 +12,8 @@
 
 from __future__ import with_statement
 
-__version__ = '0.3.3'
+__version__ = '0.3.4'
 
-import sys
 from functools import partial, wraps
 from collections import deque
 
@@ -38,7 +37,7 @@ identity_changed = signals.signal('identity-changed', doc=(
 Actual name: ``identity-changed``
 
 Authentication providers should send this signal when authentication has been
-successfully performed. Flask-IdentityContext connects to this signal and
+successfully performed. Flask-Principal connects to this signal and
 causes the identity to be saved in the session.
 
 For example::
@@ -98,21 +97,21 @@ RoleNeed.__doc__ = """A need with the method preset to `"role"`."""
 
 
 TypeNeed = partial(Need, 'type')
-TypeNeed.__doc__ = """A need with the method preset to `"role"`."""
+TypeNeed.__doc__ = """A need with the method preset to `"type"`."""
 
 
 ActionNeed = partial(Need, 'action')
 TypeNeed.__doc__ = """A need with the method preset to `"action"`."""
 
 
-ItemNeed = namedtuple('RowNeed', ['method', 'value', 'type'])
+ItemNeed = namedtuple('ItemNeed', ['method', 'value', 'type'])
 """A required item need
 
 An item need is just a named tuple, and practically any tuple will do. In
 addition to other Needs, there is a type, for example this could be specified
 as::
 
-    RowNeed('update', 27, 'posts')
+    ItemNeed('update', 27, 'posts')
     ('update', 27, 'posts') # or like this
 
 And that might describe the permission to update a particular blog post. In
@@ -163,6 +162,11 @@ class Identity(object):
         """
         return permission.allows(self)
 
+    def __repr__(self):
+        return '<{0} name="{1}" auth_type="{2}" provides={3}>'.format(
+            self.__class__.__name__, self.name, self.auth_type, self.provides
+        )
+
 
 class AnonymousIdentity(Identity):
     """An anonymous identity
@@ -254,6 +258,11 @@ class Permission(object):
         """
         return other.issubset(self)
 
+    def __repr__(self):
+        return '<{0} needs={1} excludes={2}>'.format(
+            self.__class__.__name__, self.needs, self.excludes
+        )
+
     def require(self, http_exception=None):
         """Create a principal for this permission.
 
@@ -317,8 +326,10 @@ class Permission(object):
 
         :param other: The other permission
         """
-        return self.needs.issubset(other.needs) and \
-               self.excludes.issubset(other.excludes)
+        return (
+            self.needs.issubset(other.needs) and
+            self.excludes.issubset(other.excludes)
+        )
 
     def allows(self, identity):
         """Whether the identity can access this permission.
@@ -385,8 +396,10 @@ class Principal(object):
 
     def _init_app(self, app):
         from warnings import warn
-        warn(DeprecationWarning('_init_app is deprecated, use the '
-            'new init_app method instead.'), stacklevel=1)
+        warn(DeprecationWarning(
+            '_init_app is deprecated, use the new init_app '
+            'method instead.'), stacklevel=1
+        )
         self.init_app(app)
 
     def init_app(self, app):
@@ -407,8 +420,6 @@ class Principal(object):
 
         :param identity: The identity to set
         """
-        if self._is_static_route():
-            return
 
         self._set_thread_identity(identity)
         for saver in self.identity_savers:
@@ -458,6 +469,9 @@ class Principal(object):
                              identity=identity)
 
     def _on_identity_changed(self, app, identity):
+        if self._is_static_route():
+            return
+
         self.set_identity(identity)
 
     def _on_before_request(self):
@@ -472,5 +486,7 @@ class Principal(object):
                 return
 
     def _is_static_route(self):
-        return (self.skip_static and \
-                request.path.startswith(self._static_path))
+        return (
+            self.skip_static and
+            request.path.startswith(self._static_path)
+        )
